#!/bin/sh
# Specify the paths
PSEUDO_DIR="/home/jyhuang/WS_QE/pseudo"
PW_COMMAND="/opt/QE61/bin/pw.x"
OUT_DIR="/home/jyhuang/WS_QE/scratch"
#
NAME="MoTe2"
alat=13.963
cutoff=50
#
# Mo_pvTe/66 - (66) - BCC [AB2] (66)
cat > $NAME.vcrelax.in <<EOF
 &control
    calculation='vc-relax', ! This means we're doing a variable cell relaxation
    restart_mode='from_scratch', ! This is where all the data (LARGE files!) is stored - devote some folder for this purpose
    prefix='$NAME', ! Name of the folder to be opened in the outdir. It's useful to use the smae prefix for sequental calculations, as the data produced by this calculation be be used by others
    outdir = '$OUT_DIR/', ! This is where all the data (LARGE files!) is stored - devote some folder for this purpose
    pseudo_dir = '$PSEUDO_DIR/', ! Folder where the pseudopotential files are located.
    tprnfor = .true.
    tstress = .true.
    etot_conv_thr = 1.d-2
 /
 &system
    nat = 3 ! Number of atoms in the unit cell - PbTe has two atoms in it's Rock-Salt structure
    ntyp = 2  ! Number of types of atoms
    ibrav = 0 ! type of crystal lattice - ibrav=2 means that we're using a FCC (Face Centered Cubic) cell.
    celldm(1) =$alat, ! Specifies the cell dimension - only one value is needed for a cubic lattice. I'm using an initial value of 12.4 bohr (1 bohr = 0.529177249 Angstrom)
    celldm(3) =1.0,
    ecutwfc =$cutoff ! This is the kinetic energy cutoff for wave functions (in Ry units, 1 Ry = 13.6 eV) -
    ecutrho = 400,
    occupations = 'smearing',
    smearing = 'gauss',
    degauss = 0.0001,
    nosym = .true.
    noinv = .true.
 /
 &electrons
    diagonalization = 'david',
    mixing_mode = 'plain',
    mixing_beta = 0.7,
    conv_thr =  1.0d-5
    electron_maxstep = 200,
 /
 &ions
 /
&cell
 /

CELL_PARAMETERS (angstrom)
  -1.64558558944902   1.64558558944902   7.02478477622999
   1.64558558944902  -1.64558558944902   7.02478477622999
   1.64558558944902   1.64558558944902  -7.02478477622999

ATOMIC_SPECIES
 Mo   65.38     Zn.pbe-van.UPF
 Te   18.9984    F.pbe-n-kjpaw_psl.0.1.UPF

ATOMIC_POSITIONS crystal
  Mo      -0.00000000000000   0.00000000000000   0.00000000000000  ! // Mo
  Te      0.61956932576198   0.61956932576198   -0.00000000000000  ! // Te
  Te      0.38043067423802   0.38043067423802   -0.00000000000000  ! // Te

K_POINTS AUTOMATIC
16 16 16 0 0 0
EOF

#------Actual Running Command (run MPI executable with M*N processes)------
mpirun -np 12 --map-by core $PW_COMMAND < $NAME.vcrelax.in > $NAME.vcrelax.out
