#!/bin/sh
# Specify the paths
PSEUDO_DIR="/home/jyhuang/WS_QE/pseudo"
PW_COMMAND="/opt/QE61/bin/pw.x"
PH_COMMAND="/opt/QE61/bin/ph.x"
OUT_DIR="/home/jyhuang/WS_QE/scratch"
#
NAME="Si"
alat=10.26
cutoff=30
#
#
cat > "./data/$NAME.vcrelax.in" <<EOF
 &control
    calculation='vc-relax', ! This means we're doing a variable cell relaxation
    restart_mode='from_scratch', ! This is where all the data (LARGE files!) is stored - devote some folder for this purpose
    prefix='$NAME', ! Name of the folder to be opened in the outdir. It's useful to use the smae prefix for sequental calculations, as the data produced by this calculation be be used by others
    outdir = '$OUT_DIR/', ! This is where all the data (LARGE files!) is stored - devote some folder for this purpose
    pseudo_dir = '$PSEUDO_DIR/', ! Folder where the pseudopotential files are located.
    tprnfor = .true.
 /
 &system
    nat = 2 ! Number of atoms in the unit cell - PbTe has two atoms in it's Rock-Salt structure
    ntyp = 1 ! Number of types of atoms
    ibrav = 2 ! type of crystal lattice - ibrav=2 means that we're using a FCC (Face Centered Cubic) cell.
    celldm(1) =$alat, ! Specifies the cell dimension - only one value is needed for a cubic lattice. I'm using an initial value of 12.4 bohr (1 bohr = 0.529177249 Angstrom)
    ecutwfc =$cutoff ! This is the kinetic energy cutoff for wave functions (in Ry units, 1 Ry = 13.6 eV) -
 /
 &electrons
    diagonalization = 'david',
    mixing_mode = 'plain',
    mixing_beta = 0.7,
    conv_thr =  1.0d-8
 /
 &ions
 /
&cell
 /

ATOMIC_SPECIES
Si  28.086  Si.pbe-hgh.UPF

ATOMIC_POSITIONS crystal
Si 0.00 0.00 0.00
Si 0.25 0.25 0.25

K_POINTS AUTOMATIC
4 4 4 1 1 1
EOF

#------Actual Running Command (run MPI executable with M*N processes)------
mpirun -np 12 --map-by core $PW_COMMAND < "./data/$NAME.vcrelax.in" > "./results/$NAME.vcrelax.out"
