#!/bin/sh
# Specify pathnames
PSEUDO_DIR="/home/jyhuang/WS_QE/pseudo"
OUT_DIR="/home/jyhuang/WS_QE/scratch"
PLOTBAND_COMMAND="/opt/QE61/bin/plotband.x"
#
NAME="si"
Emin=-10.
Emax=25.
Ef=5.933
Xl=$(echo "$Emin-1" |bc)
Xr=$(echo "$Emax-5" |bc)
#
#  Make files for plotting the band dispersions
cat > './data/plotband.in' <<EOF1
./results/bands.tmp
$Emin $Emax ! minimum and maximum energy range on the plot (on the y axis)
$NAME.bands.xmgr
$NAME.bands.ps
$Ef   ! Fermi energy taken from pw.x
1.0, $Ef ! delta E and value which will be marked as zero on the plot
EOF1
#
$PLOTBAND_COMMAND < ./data/plotband.in
#
# make gnuplot for the dispersion
#
cat > "./results/plot_bandstr.gnu" <<EOF2
set terminal post eps enhanced solid color "Helvetica" 20
set output "./results/$NAME_bandstr.eps"
set key off

set xrange [0:6.0656]
set yrange [$Emin:$Emax]

set arrow from 1, $Emin to 1, $Emax nohead  lw 3
set arrow from 1.5, $Emin to 1.5, $Emax nohead  lw 3
set arrow from 1.854, $Emin to 1.854, $Emax nohead  lw 3
set arrow from 2.914, $Emin to 2.914, $Emax nohead  lw 3
set arrow from 3.78, $Emin to 3.78, $Emax nohead  lw 3
set arrow from 4.393, $Emin to 4.393, $Emax nohead  lw 3
set arrow from 4.746, $Emin to 4.746, $Emax nohead  lw 3
set arrow from 5.453, $Emin to 5.453, $Emax nohead  lw 3
set arrow from 0., $Ef to 6.06, $Ef nohead lw 1

set ylabel "E (eV)"
unset xtics
set label "{/Symbol G}" at -0.05, $Xl
set label "X" at 0.95, $Xl
set label "W" at 1.4, $Xl
set label "K" at 1.80, $Xl
set label "{/Symbol G}" at 2.85, $Xl
set label "L" at 3.7, $Xl
set label "U" at 4.3, $Xl
set label "W" at 4.64, $Xl
set label "L" at 5.4, $Xl
set label "K" at 6.0, $Xl

plot "./results/$NAME.bands.xmgr" u 1:2 w l lt 1 lc 1 lw 1
EOF2
#
# make gnuplot for DOS
#
cat > './results/plot_dos.gnu' <<EOF3
set terminal post eps enhanced solid color "Helvetica" 20
set output "./results/$NAME_dos.eps"
set key off

set xrange [$Emin:$Xr]
set ylabel "DOS"
set xlabel "E (eV)"
set arrow from $Ef, 0. to $Ef, 1 nohead  lw 2

plot "./results/$NAME.dos" u 1:2 w l lw 2
EOF3
#
#plot everything and convert it to png
#
gnuplot './results/plot_bandstr.gnu'
gnuplot './results/plot_dos.gnu'
sh ../../scripts/eps2png './results/$NAME_bandstr.eps' './results/$NAME_bandstr.png'
sh ../../scripts/eps2png './results/$NAME_dos.eps' './results/$NAME_dos.png'
