#!/bin/sh
# Specify pathnames
PSEUDO_DIR="/home/jyhuang/WS_QE/pseudo"
OUT_DIR="/home/jyhuang/WS_QE/scratch"
PLOTBAND_COMMAND="/opt/QE540/plotband.x"
#
NAME="al"
Emin=-5.
Emax=35.
Ef=7.57
Xl=$(echo "$Emin-1" |bc)
Xr=$(echo "$Emax-10" |bc)
#
#  Make files for plotting the band dispersions
cat > plotband.in <<EOF1
bands.tmp
$Emin $Emax  ! minimum and maximum energy range on the plot (on the y axis)
$NAME.bands.xmgr
$NAME.bands.ps
$Ef      ! Fermi energy taken from pw.x
1.0, $Ef ! delta E and value which will be marked as zero on the plot
EOF1
#
$PLOTBAND_COMMAND < plotband.in
#
# make gnuplot for the dispersion
#
cat > plot_bandstr.gnu <<EOF2
set terminal post eps enhanced solid color "Helvetica" 20
set output "gnuplot_bandstr.eps"
set key off

set xrange [0:6.07]
set yrange [$Emin:$Emax]

set arrow from 1, $Emin to 1, $Emax nohead  lw 3
set arrow from 1.5, $Emin to 1.5, $Emax nohead  lw 3
set arrow from 1.854, $Emin to 1.854, $Emax nohead  lw 3
set arrow from 2.914, $Emin to 2.914, $Emax nohead  lw 3
set arrow from 3.78, $Emin to 3.78, $Emax nohead  lw 3
set arrow from 4.393, $Emin to 4.393, $Emax nohead  lw 3
set arrow from 4.746, $Emin to 4.746, $Emax nohead  lw 3
set arrow from 5.453, $Emin to 5.453, $Emax nohead  lw 3
set arrow from 0., $Ef to 6.06, $Ef nohead lw 1

set ylabel "E (eV)"
unset xtics
set label "{/Symbol G}" at -0.05, $Xl
set label "X" at 0.95, $Xl
set label "W" at 1.4, $Xl
set label "K" at 1.80, $Xl
set label "{/Symbol G}" at 2.85, $Xl
set label "L" at 3.7, $Xl
set label "U" at 4.3, $Xl
set label "W" at 4.64, $Xl
set label "L" at 5.4, $Xl
set label "K" at 6.0, $Xl

plot "$NAME.bands.xmgr" u 1:2 w l lt 1 lc 1 lw 1
EOF2
#
# make gnuplot for DOS
#
cat > plot_dos.gnu <<EOF3
set terminal post eps enhanced solid color "Helvetica" 20
set output "gnuplot_dos.eps"
set key off

set xrange [$Emin:$Xr]
set ylabel "DOS"
set xlabel "E (eV)"
set arrow from $Ef, 0. to $Ef, 1 nohead  lw 2

plot "$NAME.dos" u 1:2 w l lw 2
EOF3
#
#plot everything and convert it to png
#
gnuplot plot_bandstr.gnu
gnuplot plot_dos.gnu
sh ../../scripts/eps2png gnuplot_bandstr.eps gnuplot_bandstr.png
sh ../../scripts/eps2png gnuplot_dos.eps gnuplot_dos.png
